@@ -18,7 +18,7 @@
 
 import gettext
 translation=gettext.translation('setroubleshoot-plugins', fallback=True)
-_=translation.ugettext
+_=translation.gettext
 
 from setroubleshoot.util import *
 from setroubleshoot.Plugin import Plugin
@@ -31,8 +31,8 @@ class plugin(Plugin):
     problem_description = _('''
     SELinux denied samba access to $TARGET_PATH.
     If you want to share this directory with samba it has to have a file context label of
-    samba_share_t. If you did not intend to use $TARGET_PATH as a samba repository
-    it could indicate either a bug or it could signal a intrusion attempt.
+    samba_share_t. If you did not intend to use $TARGET_PATH as a samba repository,
+    this message could indicate either a bug or an intrusion attempt.
     Please refer to 'man samba_selinux' for more information on setting up Samba and SELinux.
     ''')
 
@@ -42,21 +42,29 @@ class plugin(Plugin):
     ''')
 
     fix_cmd = "chcon -R -t samba_share_t '$TARGET_PATH'"
-    
+    then_text = _("You need to change the label on '$FIX_TARGET_PATH'")
+    def get_do_text(self, avc, tclass):
+        dpath = ""
+        rflag = ""
+        if tclass == "dir":
+            dpath = "(/.*)?"
+            rflag = "-R"
+
+        return _("""# semanage fcontext -a -t samba_share_t '$FIX_TARGET_PATH%s'
+# restorecon %s -v '$FIX_TARGET_PATH'""") % (dpath, rflag)
+
     def __init__(self):
         Plugin.__init__(self, __name__)
         self.set_priority(51)
 
     def analyze(self, avc):
-        if avc.matches_source_types(['smbd_t'])                                                                              and \
-           not avc.matches_target_types(['httpd_.*_content_t', 'rsync_data_t', 'home_root_t', '.*_home_dir_t', '.*_home_t']) and \
-           avc.all_accesses_are_in(avc.create_file_perms + avc.create_dir_perms)                                             and \
-           avc.has_tclass_in(['file', 'dir'])                                                                                and \
-           avc.path_is_not_standard_directory():
+        if (avc.matches_source_types(['smbd_t'])                                                                              and
+            not avc.matches_target_types(['httpd_.*_content_t', 'rsync_data_t', 'home_root_t', '.*_home_dir_t', '.*_home_t']) and
+            avc.all_accesses_are_in(avc.create_file_perms + avc.create_dir_perms)                                             and
+            avc.has_tclass_in(['file', 'dir'])                                                                                and
+            avc.path_is_not_standard_directory()):
             # MATCH
-            return self.report(avc, _("File Label"),
-                               self.summary, self.problem_description,
-                               self.fix_description, self.fix_cmd)
+            return self.report(avc.tclass)
         else:
             return None
 
